<?php

namespace Slovocast\Handler\Channel\Episode;

use League\Flysystem\FilesystemException;
use League\Flysystem\FilesystemOperator;
use League\Flysystem\UnableToWriteFile;
use Odan\Session\SessionInterface;
use Psr\Http\Message\UploadedFileInterface;
use Psr\Log\LoggerInterface;
use Slovocast\Handler\Handler;
use Psr\Http\Message\ResponseInterface;
use Slovocast\Domain\Repository\Episode\EpisodeFileRepositoryInterface;

/**
 * Maybe call this Async? Used for
 */
class UploadEpisodeFileAction extends Handler
{
    public function __construct(
        private EpisodeFileRepositoryInterface $episodeFileRepository,
        private FilesystemOperator $filesystem,
        private SessionInterface $session,
        private LoggerInterface $logger
    ) { }

    public function handle(): ResponseInterface
    {
        /** @var array<UploadedFileInterface> */
        $files = $this->request->getUploadedFiles();

        // move the files to storage
        try {
            foreach ($files as $file) {
                $this->filesystem->writeStream($file->getStream());
            }

            return $this->json([ 'message' => 'Uploaded Episode file' ]);
        } catch (FilesystemException | UnableToWriteFile $e) {
            $this->logger->error($e->getMessage());
        }

        $errorMessage = "Unable to upload file";
        $this->session->getFlash()->add('error', $errorMessage);
        return $this->json([ 'message' => $errorMessage ]);
    }
}
